@@ -194,4 +194,10 @@ class IBLUser(IBLBaseUser):
                 self.user = None
         else:
             self.user = None
+        
+        if not self.user:
+            self.username = ""
+        else:
+            self.username = self.user["username"]
+
         super().__init__(id, json)  
